function [f] = fitFactor(ys, yv)
// Fit factor
//
// Calling Sequence
// [f] = fitFactor(ys, yv) 
//
// Parameters
//   Inputs:
//    ys: simulated data
//    yv: validation data
// 
//   Outputs:
//    f: fit factor
//
// Description
// Computes a fit factor between simulated data ys and validation data yv as
//
// f = 1 - ||yv-ys||_2 / ||yv-mean(yv)||_2
//
// See also
//  valPred
//  valSim 
  
  [LHS RHS] = argn(0);
  if (RHS ~= 2)
    error('Wrong number of input arguments. Use [f] = fitFactor(ys, yv).');
  end
  if (size(ys,1) < size(ys,2)) then
    ys = ys';
  end
  if (size(yv,1) < size(yv,2)) then
    yv = yv';
  end
  if (~and(size(ys)==size(yv))) then
    error('ys and yv must be of the same size.');
  else
      m = size(ys,2);
  end
  f = zeros(m,1);
  for i = 1:m
    f(i,1) = 1-norm(yv(:,i)-ys(:,i),'fro')/norm(yv(:,i)-mean(yv(:,i)),'fro');
  end
endfunction
