function datnew = repairtime(data,samplingPeriod)
// Data adjustment according to time line.
//
// Calling Sequence
// [datnew] = repairtime(data,samplingPeriod)   
//
// Parameters
//   Inputs:
//     data:  measured data, first row must be the time vector
//     samplingPeriod:  expected interval between two samples
//     threshold//   
//   Outputs:
//     datnew:  data without repeating time values, time gaps and equidistantly sampled
// Description
//  Adjust the time line (rounds to multiples of the sampling time), removes repeating time values (may be caused due to rounding) and identifies time line gaps and fills corresponding samples with NaN (Not a Number). The output is equidistantly sampled. 
//
// Examples
//  time = [1 1 2 5 6 7 8 10];
//  meas = [5 5 10 25 30 35 40 50];
//  data = [time;meas];
//  datnew = repairtime(data,1)
// See also
//  nanhandle
//  nanredundant

// CODE

  [LHS RHS] = argn(0);
  if (RHS ~= 2)
    error('Wrong number of input arguments. Use [datnew] = repairtime(data,samplingPeriod).')
  end
  
  // time line adjustment
  initTime = data(1,1);
  data(1,:) = round((data(1,:)-initTime)/samplingPeriod);   
  
  // remove duplicity
  red = find(diff(data(1,:))<1);
  data(:,red) = [];
  
  // repair time line
  cmis = diff(data(1,:));
  mis = find(cmis>1);
  count = cmis(mis);
  
  nan = [%nan*ones(1,size(data,1)-1)]';
  
  
  for i=1:length(mis)
    
    pred = data(:,1:mis(1));
    po = data(:,mis(1)+1:$);
    
    for j=1:count(1)-1
      data = [pred,[mis(1)+j-1;nan]];
      pred = data; 
    end
    data = [data,po]
    
    cmis = diff(data(1,:));
    mis = find(cmis>1);
    count = cmis(mis)
  end
  data(1,:)=data(1,:)+initTime;
  datnew = data;
endfunction