function [res,msRes,maxRes]=residues(yv, ys, plt)
// Computes the residues res=yv-ys.
//
// Calling Sequence
//   [res, msRes, maxRes] = residues(yv, ys) //plt=0 here
//   [res, msRes, maxRes] = residues(yv, ys, plt)
//
// Parameters
//Inputs
//   yv: vector [1,n] : input vector with validation data
//   ys: vector [1,n] : input vector with estimated data
//   plt: integer 0,1,: computes the residues, computes and plots the residues
// Outouts
//   res: vector [1,n] : output vector with the residues
//   msRes: scalar : mean square of the residues
//   maxRes: scalar : maximum absolute value of the residues
//
// Description
// Function for computing the residues of two input vectors by res=yv-ys, where yv is the known measured data vector and ys is the estimated data vector - e.g. ys can be obtained by one of the identification methods cited in See also section.
//
// Examples
//data = read('.../identification/demos/dryer.dat',-1,2);
//data = [u y];
//y = data(1:400,2); u = data(1:400,1); //identification data
//yv = data(401:$,2); uv = data(401:$,1); //validation data
//[a b vare] = arx(y,u,3,3,2);
//[fit, ys] = valSim(a, b, yv, uv);
//[res,msRes,maxRes]=residues(yv, ys, 1) // computes the residues and plot
//[res,msRes,maxRes]=residues(yv, ys); // computes the residues
//
// See also
//  arx
//  armax
//  arIdent
//  rarx
//  subspaceIdent
//  fitFactor
//
// Authors
//   
// Bibliography
//   Literature references one pr. line

// CODE \\

// input parameters check
  [LHS RHS] = argn(0);
  if (RHS ~= 2 & RHS ~= 3)
    error('Wrong number of input arguments. Use residues(yv, ys) or residues(yv, ys, plt).')
  end
  if (RHS == 2)
    plt = 0;
  end
  
  if(isempty(yv) | isempty(ys))
    error('Input vector yv or ys undefined!');
  end;
  
//  if (size(ys,1) < size(ys,2))
//    ys = ys';
//    yv = yv';
//  end;

  if (size(yv,1) < size(yv,2))
    yv = yv';
  end
  if (size(ys,1) < size(ys,2))
    ys = ys';
  end
  
  if (size(ys,1) ~= size(yv,1) | size(ys,2) ~= size(yv,2))
    error('ys and yv must be of the same size.')
  end;
  
  if(plt < 0 | plt > 1 )
    error('Incorect plt select. (plt=1:plot; plt=0:doesnt plot)');
  end;
  
  if (isempty(plt))
    plt=[0];  
  end;
    
  select plt,
    case 0,
      res=yv-ys;,
    case 1,
      res=yv-ys;
      plot(res);
//      plot(ys,res,'x');
//      plot(res,ys,'x');
      title('Residues res=yv-ys');
      xlabel('time');
      ylabel('Amplitude');
    end;
    msRes = mean(res.^2);
    maxRes = max(abs(res));
endfunction